==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PoleCsvKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.NazwaPolaCSV;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PoleCsvKey extends GenericDPSObject {
    /**
     * POLE_CSV.FORMAT_CSV_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long formatCsvId;

    /**
     * POLE_CSV.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private NazwaPolaCSV nazwa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_CSV.FORMAT_CSV_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getFormatCsvId() {
        return formatCsvId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * POLE_CSV.FORMAT_CSV_ID
     *
     * @param formatCsvId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFormatCsvId(Long formatCsvId) {
        this.formatCsvId = formatCsvId;
    }

    /**
     * @return POLE_CSV.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public NazwaPolaCSV getNazwa() {
        return nazwa;
    }

    /**
     * POLE_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(NazwaPolaCSV nazwa) {
        this.nazwa = nazwa;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleCsvKey other = (PoleCsvKey) that;
        return (this.getFormatCsvId() == null ? other.getFormatCsvId() == null : this.getFormatCsvId().equals(other.getFormatCsvId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getFormatCsvId() == null) ? 0 : getFormatCsvId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", formatCsvId=").append(formatCsvId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PoleCsvKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.NazwaPolaCSV;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PoleCsvKey extends GenericDPSObject {
    /**
     * POLE_CSV.FORMAT_CSV_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long formatCsvId;

    /**
     * POLE_CSV.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private NazwaPolaCSV nazwa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_CSV.FORMAT_CSV_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getFormatCsvId() {
        return formatCsvId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * POLE_CSV.FORMAT_CSV_ID
     *
     * @param formatCsvId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFormatCsvId(Long formatCsvId) {
        this.formatCsvId = formatCsvId;
    }

    /**
     * @return POLE_CSV.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public NazwaPolaCSV getNazwa() {
        return nazwa;
    }

    /**
     * POLE_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(NazwaPolaCSV nazwa) {
        this.nazwa = nazwa;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleCsvKey other = (PoleCsvKey) that;
        return (this.getFormatCsvId() == null ? other.getFormatCsvId() == null : this.getFormatCsvId().equals(other.getFormatCsvId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getFormatCsvId() == null) ? 0 : getFormatCsvId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", formatCsvId=").append(formatCsvId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}
